%%%
%%% Graphs
%%%

%%%

addpath ('./matlab_subroutine',-0)
Xcol = 3;
Ycol = 3;
XMAX = 200;
%%%
DIR = './../DATA_STDP/';
OFFSET = 470;
MP = [-256,-128,-64,-32,-16,-8,-4,-2,-1,...
         1, 2, 4, 8, 16, 32,64,128,256];
NUM = length(MP);

%%
%% Color
%%
clmap = zeros(0,0);
for i = 1:NUM/2;
 clmap = [clmap;[0 0 0.5+i/NUM]];
end;
for i = NUM/2:-1:1;
 clmap = [clmap;[0.5+i/NUM 0 0]];
end;
%%
GRAY = 0.3;
%%

%%%
%%% Integrated molecular activities of PP1, CaN, PKA
%%%

 TITLE = strvcat('PP1',...
		 'CaN',...
		 'PKA');

 FILENAME = strvcat('PP1_active.Co7',...
		    'activeCaN.Co9',...
		    'activePKA.Co8');

 PLOTCOLOR = [0.7,0.2,0.2;...
              0.2,0.7,0.2;...
              0.2,0.2,0.7];

 NUM2 = length(TITLE(:,1));
 TOT_DATA = zeros(NUM2+1, NUM);

%%%
 for i = 1:NUM2;
  for j = 1:NUM;
%
  data = load(sprintf('%s%g/%s',DIR, j-1, deblank(FILENAME(i,:))));
  k = 1; while (data(k,1) < OFFSET);k = k + 1;end;
  data([1:k],:) = [];
  k = 1; while (data(k,1) < OFFSET + 300);k = k + 1;end;
  data([k:end],:) = [];
%
  data(:,2) = data(:,2) - data(1,2);
  data(:,1) = data(:,1)./60;
   X = data(1,1):(data(end,1)-data(1,1))/20000:data(end,1);
   Y = interp1(data(:,1), data(:,2), X,'linear');
  TOT_DATA(i,j) = INTEGRATION([X',Y']);
%
  end;
 end;
%%%
%%% CaMKII
%%%

%%%
  for j = 1:NUM;
%%%
  data = load(sprintf('%s%g/activeCaMKII.Co11',DIR, j-1));
  TOT_DATA(end,j) = data(end,2);
%%%
 end;
%%%

%%%
%%% Graph plot
%%%

TMIN = -15;
TMAX =  30;
TMAX2 = 60;
PSIZE = 3;

%%
%%
%% Plot PKA and CaMKII
%%
%%
subplot(Xcol,Ycol,4);
 set(gca,'ActivePositionProperty','position');
 tmp = get(gca,'Position');
 set(gca,'Position',[tmp(1) tmp(2) 0.2072 0.3495]);

[AX, H1, H2] = plotyy(MP, TOT_DATA(3,:)/max(TOT_DATA(3,:)),...
		      MP, TOT_DATA(4,:), 'plot', 'plot');
%
xlabel('T_{post}-T_{pre} (ms)');
%
for j = 1:2;
 set(AX(j),'XColor', 'k');
 set(AX(j),'XLim', [-XMAX, XMAX]);
 set(AX(j),'XTick',[-200, -100, 0, 100, 200]);
 set(AX(j), 'box','off');
 set(AX(j), 'PlotBoxAspectRatio', [1,1,1]);
 set(AX(j), 'TickDir', 'out');
end;
%
set(AX(1),'YColor', 'k');
set(AX(2),'YColor', 'b');
%
set(AX(1),'YLim', [-0.1, 1.1]);
set(AX(2),'YLim', [-3, 33]);
set(AX(1),'YTick',[0, 0.5, 1]);
set(AX(2),'YTick',[0, 10, 20, 30]);
%
set(get(AX(1),'Ylabel'),'String', 'Total activity (\muM\cdotmin)');
set(get(AX(2),'Ylabel'),'String', 'Final CaMKII (\muM)');
%
set(H1,'Linestyle','-',...
          'Color',PLOTCOLOR(3,:),...
          'Marker', 'o',...
          'MarkerSize', PSIZE,...
          'MarkerFaceColor', PLOTCOLOR(3,:), ...
          'MarkerEdgeColor', PLOTCOLOR(3,:));
set(H2,'Linestyle','-',...
          'Color','b',...
          'Marker', 'o',...
          'MarkerSize', PSIZE,...
          'MarkerFaceColor', 'b', ...
          'MarkerEdgeColor', 'b');
%
axes(AX(1));
hold on;
 for j = 1:NUM;
  plot (MP(j), TOT_DATA(3,j)/max(TOT_DATA(3,:)),'o','MarkerSize', PSIZE-1.5,...
          'MarkerFaceColor', clmap(j,:), ...
          'MarkerEdgeColor', clmap(j,:));
 end;
hold off;
%
axes(AX(2));
hold on;
 for j = 1:NUM;
  plot (MP(j), TOT_DATA(4,j),'o','MarkerSize', PSIZE-1.5,...
          'MarkerFaceColor', clmap(j,:), ...
          'MarkerEdgeColor', clmap(j,:));
 end;
hold off;
%
LEG1 = sprintf('%s/%1.2f',  deblank(TITLE(3,:)), max(TOT_DATA(3,:)));
h = legend([H1, H2], LEG1,'CaMKII');
%set(h, 'Visible','off');
%set(allchild(h),'visible','on');
%set(h, 'Fontsize', 8);
%

%%
%%
%% Plot CaN and PP1
%%
%%

subplot(Xcol,Ycol,6);
 set(gca,'ActivePositionProperty','position');
 tmp = get(gca,'Position');
 set(gca,'Position',[tmp(1) tmp(2) 0.2072 0.3495]);
i = 1;
H1 = plot(MP, TOT_DATA(i,:)/max(TOT_DATA(i,:)));
%
xlabel('T_{post}-T_{pre} (ms)');
ylabel('Total activity (\muM\cdotmin)');
axis square;
axis([-XMAX, XMAX, -0.1, 1.1]);
set (gca, 'XTick', [-200, -100, 0, 100, 200]);
box off;
set (gca, 'TickDir', 'out');
set(H1,'Linestyle','-',...
          'Color',PLOTCOLOR(i,:),...
          'Marker', 'o',...
          'MarkerSize', PSIZE,...
          'MarkerFaceColor', PLOTCOLOR(i,:), ...
          'MarkerEdgeColor', PLOTCOLOR(i,:));
%
hold on;
i = 2;
H2 = plot(MP, TOT_DATA(i,:)/max(TOT_DATA(i,:)));
set(H2,'Linestyle','-',...
          'Color',PLOTCOLOR(i,:),...
          'Marker', 'o',...
          'MarkerSize', PSIZE,...
          'MarkerFaceColor', PLOTCOLOR(i,:), ...
          'MarkerEdgeColor', PLOTCOLOR(i,:));
for i = 1:2;
 for j = 1:NUM;
  plot(MP(j), TOT_DATA(i,j)/max(TOT_DATA(i,:)),'o','MarkerSize', PSIZE-1.5,...
          'MarkerFaceColor', clmap(j,:), ...
          'MarkerEdgeColor', clmap(j,:));
 end;
end;
hold off;
%
i=1;LEG1 = sprintf('%s/%1.2f',  deblank(TITLE(i,:)), max(TOT_DATA(i,:)));
i=2;LEG2 = sprintf('%s/%1.2f',  deblank(TITLE(i,:)), max(TOT_DATA(i,:)));
h = legend([H1, H2], LEG1,LEG2);
%set(h, 'Visible','off');
%set(allchild(h),'visible','on');
%set(h, 'Fontsize', 8);
%

%%
