%%%
%%% Graphs
%%%

%%%

addpath ('./matlab_subroutine',-0)
Xcol = 2;
Ycol = 3;

%%%

MP = [-115, -105, -95, -85, -75, -65, -55, -45, -35, -25];

NUM = length(MP);
DIR = './../DATA_Volt/';
colormap(jet(NUM));
clmap = colormap;
OFFSET = 499;

%%%
%%% Integrated molecular activity
%%%

 TITLE = strvcat('PP1',...
		 'CaN',...
		 'PKA');

 FILENAME = strvcat('PP1_active.Co7',...
		    'activeCaN.Co9',...
		    'activePKA.Co8');

 PLOTCOLOR = [0.7,0.2,0.2;...
              0.2,0.7,0.2;...
              0.2,0.2,0.7;...
                0,  0,  0];

 NUM2 = length(TITLE(:,1));

%%%

 TOT_DATA = zeros(NUM2, NUM);

%%%
 for i = 1:NUM2;
  for j = 1:NUM;
%%%
  data = load(sprintf('%s%g/%s',DIR, j-1, deblank(FILENAME(i,:))));
  k = 1; while (data(k,1) < OFFSET);k = k + 1;end;
  data([1:k],:) = [];
  k = 1; while (data(k,1) < OFFSET + 300);k = k + 1;end;
  data([k:end],:) = [];

  data(:,2) = data(:,2) - data(1,2);
  data(:,1) = data(:,1)./60;
   X = data(1,1):(data(end,1)-data(1,1))/10000:data(end,1);
   Y = interp1(data(:,1), data(:,2), X,'cubic');
%%%
%%%   if  i == 2;
%%%   if  j > 8;
%%%   subplot(Xcol,Ycol,[2 3 5 6]);
%%%   axis([1450/60, 2000/60, -0.1, 2]);
%%%   hold on;
%%%   plot (X,Y,'-','Color',[j-9,0,0]);
%%%   hold off;
%%%   end;
%%%   end;
%%%
  X_old = X;
  Y_old = Y;
  TOT_DATA(i,j) = INTEGRATION([X',Y']);
%%%
  end;
 end;
%%%



%%%
%%% CaMKII activity
%%%


 CaMKII = zeros(1, NUM);

%%%
  for j = 1:NUM;
%%%
  data = load(sprintf('%s%g/activeCaMKII.Co11',DIR, j-1));
  k = 1; while (data(k,1) < OFFSET);k = k + 1;end;
  CaMKII(1,j) = data(end,2);
%%%
 end;
%%%

%%%
%%% Graph plot
%%%

TMIN = -15;
TMAX =  30;
TMAX2 = 60;
PSIZE = 3;
%
%
colormap(jet(NUM));
clmap = colormap;
%
%
subplot(Xcol,Ycol,1);
set(gca,'ActivePositionProperty','position');
tmp2 = get(gca,'Position');
set(gca,'Position',[tmp2(1) tmp2(2) 0.2072 0.3495]);

[AX, H1, H2] = plotyy(MP, TOT_DATA(1,:)/max(TOT_DATA(1,:)), MP, CaMKII(1,:), 'plot', 'plot');

set(AX(1),'XLim', [min(MP), max(MP)]);
set(AX(1),'YLim', [-0.1, 1.1]);
set(AX(2),'XLim', [min(MP), max(MP)]);
set(AX(2),'YLim', [-4, 44]);

set(AX(1),'XColor', 'k');
set(AX(2),'XColor', 'k');

set(AX(1),'YColor', 'k');
set(AX(2),'YColor', 'b');

set(AX(1),'XTick',[-105, -85, -65, -45, -25]);
set(AX(2),'XTick',[-105, -85, -65, -45, -25]);
set(AX(1),'YTick',[0, 0.5, 1]);
set(AX(2),'YTick',[0, 20, 40, 60, 80]);

set(AX(1), 'box','off');
set(AX(2), 'box','off');

set(AX(1), 'PlotBoxAspectRatio', [1,1,1]);
set(AX(2), 'PlotBoxAspectRatio', [1,1,1]);

set(AX(1), 'TickDir', 'out');
set(AX(2), 'TickDir', 'out');
%
xlabel('Membrane pot (mV)');
%
set(get(AX(1),'Ylabel'),'String', 'Total activity (\muM\cdotmin)');
set(get(AX(2),'Ylabel'),'String', 'Final CaMKII (\muM)');
%
set(H1,'Linestyle','-',...
          'Color',PLOTCOLOR(1,:),...
          'Marker', 'o',...
          'MarkerSize', PSIZE,...
          'MarkerFaceColor', PLOTCOLOR(1,:), ...
          'MarkerEdgeColor', PLOTCOLOR(1,:));
set(H2,'Linestyle','-',...
          'Color','b',...
          'Marker', 'o',...
          'MarkerSize', PSIZE,...
          'MarkerFaceColor', 'b', ...
          'MarkerEdgeColor', 'b');
%
%
hold on;
%
FIGNUM = zeros(0,0);
for i = 2:NUM2;
  tmp = plot (MP, TOT_DATA(i,:)/max(TOT_DATA(i,:)),...
	  'o-','MarkerSize', PSIZE,...
          'Color',PLOTCOLOR(i,:),...
          'MarkerFaceColor', PLOTCOLOR(i,:), ...
          'MarkerEdgeColor', PLOTCOLOR(i,:));
  FIGNUM = [FIGNUM, tmp];
end;
%
hold off;
%
axes(AX(1));
hold on;
 for i = 1:NUM2;
 for j = 1:NUM;
  plot (MP(j), TOT_DATA(i,j)/max(TOT_DATA(i,:)),'o','MarkerSize', PSIZE-1.5,...
          'MarkerFaceColor', clmap(j,:), ...
          'MarkerEdgeColor', clmap(j,:));
 end;
 end;
hold off;
%
axes(AX(2));
hold on;
 for j = 1:NUM;
  plot (MP(j), CaMKII(1,j),'o','MarkerSize', PSIZE-1.5,...
          'MarkerFaceColor', clmap(j,:), ...
          'MarkerEdgeColor', clmap(j,:));
 end;
hold off;
%
hold on;
%

 i = 1; LEG1 = sprintf('%s/%1.2f',  deblank(TITLE(i,:)), max(TOT_DATA(i,:)));
 i = 2; LEG2 = sprintf('%s/%1.2f',  deblank(TITLE(i,:)), max(TOT_DATA(i,:)));
 i = 3; LEG3 = sprintf('%s/%1.2f',  deblank(TITLE(i,:)), max(TOT_DATA(i,:)));
% i = 4; LEG4 = sprintf('%s/%1.2f',  deblank(TITLE(i,:)), max(TOT_DATA(i,:)));

%h = legend([H1, FIGNUM, H2], LEG1,LEG2,LEG3,LEG4,'CaMKII');
h = legend([H1, FIGNUM, H2], LEG1,LEG2,LEG3,'CaMKII');

%set(h, 'Visible','off');
%set(allchild(h),'visible','on');
%set(h, 'Fontsize', 8);
%
%
