// genesis

//
// Create L-type Ca2+ channel formulated by Poirazi et al, 2003
//
// Programmed by H Urakubo, 6/2005
//

float offset = 0.001
float PI = 3.1415926

function make_CaL
//
	str T = "CaL"
	float Eca = 0  // in mV
//
// Throughout the present study, voltage dependence of Ca2+ current
// is described as V/(1-exp(0.0756*V)). Here, we explained the voltage
// dependence in the table of Z gate, and connected the 'tabchannel'
// object to compartments via INJECT message, in consideration of 
// the following definition.
//
// dVm/dt = {(Em - Vm)/Rm + SUM[(Ek - Vm)*Gk] 
// + (Vm' - Vm)/Ra' + (Vm'' - Vm)/Ra + inject}/Cm
//

	float tab_divs = 400
	float tab_min = -100 // in mV
	float tab_max =  100 // in mV

	int i
	float v, dv, div
	float max, tau, alpha, beta

	create   tabchannel {T}
	setfield {T} Ek {Eca} Ik 0 Gk 0 Xpower 3 Ypower 1 Zpower 0

//
// m gate
//

	call {T} TABCREATE X {tab_divs} {tab_min} {tab_max}
	v = {tab_min} - {offset}
	dv = ({tab_max} - {tab_min}) / {tab_divs}
//
	for (i = 0; i <= ({tab_divs}); i = i + 1)
		max = 1 / {1 + {exp {{v + 37}/-1}}}
		tau = 3.6
		setfield {T} X_A->table[{i}] {tau * 0.001} // in sec
		setfield {T} X_B->table[{i}] {max}
		v = v + dv
	end
//
	tweaktau {T} X
	setfield {T} X_A->calc_mode 1 X_B->calc_mode 1

//
// h gate
//
	call {T} TABCREATE Y {tab_divs} {tab_min} {tab_max}
	v = {tab_min} - {offset}
	dv = ({tab_max} - {tab_min}) / {tab_divs}
//
	for (i = 0; i <= ({tab_divs}); i = i + 1)
		max = 1 / {1+{exp {{v + 41} / 0.5}}}
		tau = 29
		setfield {T} Y_A->table[{i}] {tau * 0.001} // in sec
		setfield {T} Y_B->table[{i}] {max}
		v = v + dv
	end
//
	tweaktau {T} Y
	setfield {T} Y_A->calc_mode 1 Y_B->calc_mode 1

//
// i gate
//
        call {T} TABCREATE Z {tab_divs} {tab_min} {tab_max}
        v = {tab_min} - {offset}
        dv = ({tab_max} - {tab_min}) / {tab_divs}
        //
        for (i = 0; i <= ({tab_divs}); i = i + 1)
                max = {v / {1-{exp {0.0756*v}}}}
		if ({ abs {v} } < 0.5)
		max = {-1 / 0.0756 * {1 - 0.0378 * {v}}}
		end
                setfield {T} Z_A->table[{i}] {max}
                setfield {T} Z_B->table[{i}] {1.0}
                v = v + dv
        end
        //
        setfield {T} instant {INSTANTZ}
        setfield {T} Z_A->calc_mode 1 Z_B->calc_mode 1
        //
//
	addmsg {T} . INJECT Gk
	addmsg . {T} VOLTAGE Vm
	addmsg . {T} CONCEN  Vm
//

end
