// genesis

//
// Create delayed rectifier K channel formulated by
// Migliore et al., 1999 in J Comput Neurosci 7 pp 5-15
//
// Programmed by H Urakubo, 5/2005
//

float offset = 0.001 //in mV
float PI = 3.1415926

function make_DR_K

	str T = "DR_K"
	float Ek =  -90 // in mV

	float tab_divs = 2000
	float tab_min = -100 //in mV
	float tab_max =  100  //in mV

	int i
	float v, dv, div
	float max, tau, alpha, beta

//
	create   tabchannel DR_K
	setfield {T} Ek {Ek} Ik 0 Gk 0 Xpower 1 Ypower 0 Zpower 0
//

//
// n gate
//
	call {T} TABCREATE X {tab_divs} {tab_min} {tab_max}
	v = {tab_min} - {offset}
	dv = ({tab_max} - {tab_min}) / {tab_divs}
	//
	for (i = 0; i <= ({tab_divs}); i = i + 1)

		alpha = {exp {-0.11333*{v-13}}}
		beta  = {exp {-0.07933*{v-13}}}

		max = 1 / {1 + {alpha}}
		tau = {50*{beta}} / {1 + {alpha}}
                if (tau < 2)
                        tau = 2
                end

		setfield {T} X_A->table[{i}] {tau * 0.001} // in sec
		setfield {T} X_B->table[{i}] {max}
		v = v + dv

	end
	//
	tweaktau {T} X
	setfield {T} X_A->calc_mode 1 X_B->calc_mode 1

	//
	addmsg {T} . CHANNEL Gk Ek
	addmsg . {T} VOLTAGE Vm

end
