//genesis

float PI = 3.1415926

//
// Create a CA1 neuron with the channels
// by Migliore et al., 1999
// in J Comput Neurosci 7 pp 5-15
//
// Programmed by H Urakubo, 5/2005
//

//      length (um)  diameter (um)  area(um2)
// Soma   20		20		1256.6
// dend	  40		2		251.3
//

//
// Ra: 150 ohm cm => 
//


//
// Units
//
// Cm: nF
// Rm: Gohm
// Em,initVm: mV
// Ra: Gohm 
// dia,len: um
//

function make_cell

int dend_NUM = 20
int i
str OBJ, CHAN
float tmp, current

create neutral /cell

// Create Dendritic and Somatic Compartments

create compartment /cell/soma
setfield /cell/soma Rm 2.228 Cm 1256.6e-5 Em -65 \
	Ra 0.00960 dia 20 len 20 inject 0
for (i = 1; i <= ({dend_NUM}); i = i + 1)
 create compartment /cell/dendrite[{i}]
 setfield /cell/dendrite[{i}] Rm {11.1421/2} Cm 502.4e-5 Em -65 \
	Ra 0.01909 dia 2 len 40 inject 0
end

// Insert Active Channels

pushe /cell/soma
 make_Na_soma
 make_DR_K
 make_A_Kprox

 setfield Na_soma Gbar {PI*{getfield . dia}*{getfield . len}*0.32}
 setfield DR_K Gbar    {PI*{getfield . dia}*{getfield . len}*0.1}
 setfield A_Kprox Gbar {PI*{getfield . dia}*{getfield . len}*0.48}
pope


for (i = 1; i <= ({dend_NUM}); i = i + 1)
 pushe /cell/dendrite[{i}]
 make_Na_dend
 make_DR_K

 setfield Na_dend Gbar {PI*{getfield . dia}*{getfield . len}*0.32}
 setfield DR_K Gbar    {PI*{getfield . dia}*{getfield . len}*0.1/2}

 tmp = {{{i} * 40} - 10}
 if (tmp > 400)
 tmp = 400
 end
 tmp = {tmp / 100}
 echo {0.48*{1 + {tmp}}}
 if (tmp < 1)
	make_A_Kprox
 	setfield A_Kprox Gbar \
         {{PI}*{getfield . dia}*{getfield . len}*0.48*{1 + {tmp}}}
 end

 if (tmp >= 1)
	make_A_Kdist
 	setfield A_Kdist Gbar \
         {{PI}*{getfield . dia}*{getfield . len}*0.48*{1 + {tmp}}}
 end
 pope
end

// Fix the Resting Potential


foreach  OBJ ({el /cell/#[][TYPE=compartment]})
	call {OBJ} RESET
	current = 0
	foreach  CHAN ({el {OBJ}/#[][TYPE=tabchannel]})
		call {CHAN} RESET
		call {CHAN} PROCESS
		current = {current} + {getfield {CHAN} Ik}
	end
	tmp = {getfield {OBJ} Em} - {current} * {getfield {OBJ} Rm}
	setfield {OBJ} Em {tmp}
	echo {OBJ} {tmp}
end

foreach  OBJ ({el /cell/#[][TYPE=compartment]})
	setfield {OBJ} initVm -65
end

// Connect Compartments

addmsg /cell/soma /cell/dendrite[1] RAXIAL Ra Vm
addmsg /cell/dendrite[1] /cell/soma AXIAL Vm
for (i = 2; i <= ({dend_NUM}); i = i + 1)
addmsg /cell/dendrite[{i-1}] /cell/dendrite[{i}] RAXIAL Ra Vm
addmsg /cell/dendrite[{i}] /cell/dendrite[{i-1}] AXIAL     Vm
end
//
end
