// genesis

//
// Create somatic Na channel formulated by Migliore et al., 1999
// in J Comput Neurosci 7 pp 5-15
//
// Programmed by H Urakubo, 5/2005
//

float offset = 0.001
float PI = 3.1415926

function make_Na_dend

	str T = "Na_dend"
	float Ena = 55  // in mV

	float tab_divs = 2000
	float tab_min = -100 //in mV
	float tab_max =  100  //in mV

	int i
	float v, dv, div
	float max, tau, alpha, beta

	create   tabchannel {T}
	setfield {T} Ek {Ena} Ik 0 Gk 0 Xpower 3 Ypower 1 Zpower 1
//

//
// m gate
//
	call {T} TABCREATE X {tab_divs} {tab_min} {tab_max}

	v = {tab_min} - {offset}
	dv = ({tab_max} - {tab_min}) / {tab_divs}
	//
	for (i = 0; i <= ({tab_divs}); i = i + 1)

		alpha = {0.4*{v + 30}} / {1-{exp {({-v-30}/7.2)}}}
		beta  = {0.124*{v + 30}} / {{exp {({v+30}/7.2)}}-1}

		max = {alpha} / {alpha + beta}
		tau = 0.5 / {alpha + beta}
		if (tau < 0.02)
			tau = 0.02
		end

		setfield {T} X_A->table[{i}] {tau * 0.001} // in sec
		setfield {T} X_B->table[{i}] {max}

		v = v + dv

	end
	//
	tweaktau {T} X
	setfield {T} X_A->calc_mode 1 X_B->calc_mode 1


//
// h gate
//
	call {T} TABCREATE Y {tab_divs} {tab_min} {tab_max}

	v = {tab_min} - {offset}
	dv = ({tab_max} - {tab_min}) / {tab_divs}
	//
	for (i = 0; i <= ({tab_divs}); i = i + 1)

		alpha = {0.03*{v + 45}} / {1-{exp {({-v-45}/1.5)}}}
		beta  = {0.01*{v + 45}} / {{exp {({v+45}/1.5)}}-1}

		max = {1 / {1+{exp {({v+50}/4)}}}}
		tau = {0.5 / {alpha + beta}}
		if (tau < 0.5)
			tau = 0.5
		end

		setfield {T} Y_A->table[{i}] {tau * 0.001} // in sec
		setfield {T} Y_B->table[{i}] {max}

		v = v + dv
	end
	//
	tweaktau {T} Y
	setfield {T} Y_A->calc_mode 1 Y_B->calc_mode 1


//
// i gate
//
	call {T} TABCREATE Z {tab_divs} {tab_min} {tab_max}

	v = {tab_min} - {offset}
	dv = ({tab_max} - {tab_min}) / {tab_divs}
	//
	for (i = 0; i <= ({tab_divs}); i = i + 1)

		alpha = {exp {0.45*{v+60}}}
		beta  = {exp {0.09*{v+60}}}

		max = {1 + 0.5*{exp {{v+58}/2}}} / {1+{exp {{v+58}/2}}}
		tau = {beta} / {0.0003*{1 + alpha}}
		if (tau < 10)
			tau = 10
		end

		setfield {T} Z_A->table[{i}] {tau * 0.001} // in sec
		setfield {T} Z_B->table[{i}] {max}

		v = v + dv
	end
	//
	tweaktau {T} Z
	setfield {T} Z_A->calc_mode 1 Z_B->calc_mode 1

//
//
//
	addmsg {T} . CHANNEL Gk Ek
	addmsg . {T} VOLTAGE Vm
	addmsg . {T} CONCEN  Vm
//
end


