//genesis
//
// For demonstration of Migliore CA1 cell on GENESIS.
// H Urakubo, 5/2005
//

//
include Na_soma
include Na_dend
include DR_K
include A_Kprox
include A_Kdist
include Migliore_cell
//
make_cell


//
// Parameters 
//
str TARGET = "/cell/dendrite[8]"

float INITCURR = 500
float INITCOND = 5

float tmax = 1
float dt = 0.0001
setclock 0 {dt}


//
// Functions
//


// Time control

//function step_tmax
// step {tmax} -time
//end



// Synaptic input

create SYN_object /cell/input
setfield /cell/input Esyn 0 Gmax {INITCOND} tau 0.003
addmsg {TARGET} /cell/input VOLTAGE Vm
addmsg /cell/input {TARGET} INJECT Isyn

function EPSP(P)
 float P
 setfield  /cell/input G1 {{getfield /cell/input G1}+P}
 setfield  /cell/input G2 {{getfield /cell/input G2}+P}
end


// Current

create SYN_object /cell/curr
setfield /cell/curr Gmax {INITCURR} tau 0.0005
addmsg /cell/curr /cell/soma INJECT G

function CURRENT_INJECTION
 setfield  /cell/curr G1 {{getfield /cell/input G1}+1}
 setfield  /cell/curr G2 {{getfield /cell/input G2}+1}
end


// Control

function set_inject(dialog)
 str dialog
 setfield /cell/curr Gmax {getfield {dialog} value}
end

function set_conductance(dialog)
 str dialog
 setfield /cell/input Gmax {getfield {dialog} value}
end


// Run control


function func_run_curr

 step 0.020 -t
 CURRENT_INJECTION
 step 0.020 -t
end

function func_run_EPSP

 step 0.018 -t
 EPSP 1
 step 0.022 -t

end

function func_run_BOTH

 step 0.018 -t
 EPSP 1
 step 0.002 -t
 CURRENT_INJECTION
 step 0.020 -t

end

function make_control
 create xform   /control [10,50,500,190]
 create xlabel  /control/label -hgeom 50 -bg cyan -label "CONTROL PANEL"
 create xbutton /control/RESET -wgeom 20% -script reset
 create xbutton /control/RUN_CURR   -xgeom 0:RESET -ygeom 0:label -wgeom 20% -script func_run_curr
 create xbutton /control/RUN_EPSP   -xgeom 0:RUN_CURR -ygeom 0:label -wgeom 20% -script func_run_EPSP
 create xbutton /control/RUN_BOTH   -xgeom 0:RUN_EPSP -ygeom 0:label -wgeom 20% -script func_run_BOTH
 create xbutton /control/QUIT -xgeom 0:RUN_BOTH -ygeom 0:label -wgeom 20% -script quit
 create xdialog /control/Injection -label "I (pico amperes) 1 msec" -value {INITCURR} -script "set_inject <widget>"
 create xdialog /control/Conductance -label "Conductance" -value {INITCOND} -script "set_conductance <widget>"
 xshow /control
end

// Graph

function make_graph
 float vmin = -80
 float vmax = 40
 float tmax = 0.04
 create xform /data [260, 50, 350, 350]
 create xlabel /data/label -hgeom 10% -label "Migliore cell"
 create xgraph /data/voltage -hgeom 90% -title "Membrane Potential"
 setfield ^ XUnits sec YUnits mvolt
 setfield ^ xmax {tmax} ymin {vmin} ymax {vmax}
 xshow /data
end

// Graph2

function make_graph2
 float vmin = 0
 float vmax = 50
 float tmax = 0.04
 create xform /data2 [{260 + 350}, 50, 350, 350]
 create xlabel /data2/label -hgeom 10% -label "Migliore cell"
 create xgraph /data2/voltage -hgeom 90% -title "Active channel conductance"
 setfield ^ XUnits sec YUnits Gohm
 setfield ^ xmax {tmax} ymin {vmin} ymax {vmax}
 xshow /data2
end


// Graph2

function make_graph3
 float vmin = 0
 float vmax = 1
 float tmax = 0.04
 create xform /data3 [{260 + 700}, 50, 350, 350]
 create xlabel /data3/label -hgeom 10% -label "Migliore cell"
 create xgraph /data3/voltage -hgeom 90% -title "A-K states"
 setfield ^ XUnits sec YUnits (1)
 setfield ^ xmax {tmax} ymin {vmin} ymax {vmax}
 xshow /data3
end


//
// Main script
//

make_control

make_graph

addmsg /cell/soma /data/voltage PLOT Vm *soma *red
addmsg /cell/dendrite[5] /data/voltage PLOT Vm *dend5 *green
addmsg /cell/dendrite[10] /data/voltage PLOT Vm *dend10 *blue
addmsg /cell/dendrite[15] /data/voltage PLOT Vm *dend15 *yellow
addmsg /cell/dendrite[20] /data/voltage PLOT Vm *dend20 *BlueViolet
//addmsg {TARGET} /data/voltage PLOT Vm *target *white

make_graph2

addmsg {TARGET}/Na_dend /data2/voltage PLOT Gk *GNa *blue
addmsg {TARGET}/DR_K /data2/voltage PLOT Gk *GDR-K *green
addmsg {TARGET}/A_Kdist /data2/voltage PLOT Gk *GA-K *yellow

make_graph3

addmsg {TARGET}/A_Kdist /data3/voltage PLOT X *A-Kn *blue
addmsg {TARGET}/A_Kdist /data3/voltage PLOT Y *A-Kl *yellow


/*
addmsg /cell/soma /data/voltage PLOT Vm *volts *red
addmsg /cell/soma/Na_soma /data/voltage PLOT Ik *INa *blue
addmsg /cell/soma/DR_K /data/voltage PLOT Ik *IDR-K *green
addmsg /cell/soma/A_Kprox /data/voltage PLOT Ik *IA-K *yellow
*/
/*
addmsg /cell/soma/Na_soma /data/voltage PLOT Ik *INa *blue
addmsg /cell/soma/DR_K /data/voltage PLOT Ik *IDR-K *green
addmsg /cell/soma/A_Kprox /data/voltage PLOT Ik *IA-K *yellow
*/
/*
addmsg /cell/dendrite[18]/Na_dend /data/voltage PLOT Ik *INa *blue
addmsg /cell/dendrite[18]/DR_K /data/voltage PLOT Ik *IDR-K *green
addmsg /cell/dendrite[18]/A_Kdist /data/voltage PLOT Ik *IA-K *yellow
*/
/*
addmsg /cell/soma/Na_soma /data2/voltage PLOT Gk *GNa *blue
addmsg /cell/soma/DR_K /data2/voltage PLOT Gk *GDR-K *green
addmsg /cell/soma/A_Kprox /data2/voltage PLOT Gk *GA-K *yellow
*/




//
check 
reset

