// genesis

//
// Create somatic Na channel formulated by Poirazi et al., 2003
// in Neuron
//
// Programmed by H Urakubo, 6/2005
//

float offset = 0.001
float PI = 3.1415926

function make_Na_soma(NaATT)
float NaATT
//
	str T = "Na_soma"
	float Ena = 55  // in mV

	float tab_divs = 400
	float tab_min = -100 // in mV
	float tab_max =  100 // in mV

	int i
	float v, dv, div
	float max, tau, alpha, beta

	create   tabchannel {T}
	setfield {T} Ek {Ena} Ik 0 Gk 0 Xpower 2 Ypower 1 Zpower 1
//

//
// m gate
//

	call {T} TABCREATE X {tab_divs} {tab_min} {tab_max}
	v = {tab_min} - {offset}
	dv = ({tab_max} - {tab_min}) / {tab_divs}
//
	for (i = 0; i <= ({tab_divs}); i = i + 1)
		max = 1 / {1 + {exp {{v + 44}/-3}}}
		tau = 0.05
		setfield {T} X_A->table[{i}] {tau * 0.001} // in sec
		setfield {T} X_B->table[{i}] {max}
		v = v + dv
	end
//
	tweaktau {T} X
	setfield {T} X_A->calc_mode 1 X_B->calc_mode 1
//

//
// h gate
//
	call {T} TABCREATE Y {tab_divs} {tab_min} {tab_max}
	v = {tab_min} - {offset}
	dv = ({tab_max} - {tab_min}) / {tab_divs}
//
	for (i = 0; i <= ({tab_divs}); i = i + 1)
		max = 1 / {1+{exp {{v + 49} / 3.5}}}
		tau = 1
		setfield {T} Y_A->table[{i}] {tau * 0.001} // in sec
		setfield {T} Y_B->table[{i}] {max}
		v = v + dv
	end
//
	tweaktau {T} Y
	setfield {T} Y_A->calc_mode 1 Y_B->calc_mode 1
//


//
// i gate
//
	call {T} TABCREATE Z {tab_divs} {tab_min} {tab_max}
	v = {tab_min} - {offset}
	dv = ({tab_max} - {tab_min}) / {tab_divs}
//
	for (i = 0; i <= ({tab_divs}); i = i + 1)
		max = {1 + NaATT*{exp {{v + 60}/2}}} / {1+{exp {{v + 60}/2}}}
		alpha = {exp {1.e-3 * 12 * {v + 60} * 37.07}}
		beta  = {exp {1.e-3 * 2.4 * {v + 60} * 37.07}}
		tau = {beta} / {0.0003 + 0.0003 * {alpha}}
		if (tau < 3)
			tau = 3
		end

		setfield {T} Z_A->table[{i}] {tau * 0.001} // in sec
		setfield {T} Z_B->table[{i}] {max}

		v = v + dv
	end
	//
	tweaktau {T} Z
	setfield {T} Z_A->calc_mode 1 Z_B->calc_mode 1
//
//
	addmsg {T} . CHANNEL Gk Ek
	addmsg . {T} VOLTAGE Vm
	addmsg . {T} CONCEN  Vm
// 

end


