//genesis

float PI = 3.1415926

//
// Create a CA1 neuron with the channels
// by Poirazi et al., 2003
// in Neuron Vol. 37, pp 977- 987
//
// Programmed by H Urakubo, 6/2005
//

//      length (um)  diameter (um)  area(um2)
// Soma   20		20		1256.6
// dend	  40		2		251.3
//

// Ra: 150 ohm cm => 

// Units

// Cm: nF
// Rm: Gohm
// Em,initVm: mV
// Ra: Gohm 
// dia,len: um

function make_cell

int dend_NUM = 20
int i
str OBJ, CHAN
float tmp, tmp2, xdist, current

float max_ar2 = 0.95
float min_ar2 = 0.30
float decay_end = 300.0
float decay_start = 50.0

create neutral /cell

// Create Dendritic and Somatic Compartments

create compartment /cell/soma
setfield /cell/soma dia 20 len 20 Em -65 inject 0
setfield /cell/soma Rm 2.228 Cm 1256.6e-5 Ra 0.00960
for (i = 1; i <= ({dend_NUM}); i = i + 1)
 create compartment /cell/dendrite[{i}]
 setfield /cell/dendrite[{i}] dia 2 len 40 Em -65 inject 0
 setfield /cell/dendrite[{i}] Rm {11.1421/2} Cm 502.4e-5 Ra 0.01909
end

// Insert Active Channels

/*
pushe /cell/soma
 make_Na_soma 0.95
 make_DR_K_soma
 make_A_Kprox
 make_CaL

 setfield Na_soma   Gbar {PI*{getfield . dia}*{getfield . len}*0.07}
 setfield DR_K_soma Gbar {PI*{getfield . dia}*{getfield . len}*0.014}
 setfield A_Kprox   Gbar {PI*{getfield . dia}*{getfield . len}*0.075}
 setfield CaL	    Gbar \
	{PI*{getfield . dia}*{getfield . len}*1.4/15*10}
pope
*/

for (i = 1; i <= ({dend_NUM}); i = i + 1)
 xdist = {{{i} * 40} - 10}

 tmp = {xdist - decay_start}/{decay_end - decay_start}
 tmp2 = {tmp > 0}*{tmp < 1}*{max_ar2 - {max_ar2 - min_ar2}*{tmp}} \
	+ {tmp <= 0}*{max_ar2} \
	+ {tmp >= 1}*{min_ar2}

 pushe /cell/dendrite[{i}]
 make_Na_dend {tmp2}
 make_DR_K_dend

 setfield Na_dend Gbar   {PI*{getfield . dia}*{getfield . len}*0.07}
 setfield DR_K_dend Gbar {PI*{getfield . dia}*{getfield . len}*0.00867}

 if (xdist < 100)
	make_A_Kprox
 	setfield A_Kprox Gbar \
         {{PI} * {getfield . dia} * {getfield . len} * 0.075}
	echo 0.075
 end
 if (xdist >= 100)
	tmp = {xdist}
	tmp = {tmp / 350} * {tmp < 350} + {tmp >= 350}
	tmp = {tmp} * 6.5 * 0.07488
	make_A_Kdist
 	setfield A_Kdist Gbar \
         {{PI} * {getfield . dia} * {getfield . len} * {tmp}}
	echo {tmp}
 end


 make_CaL
 if (xdist > 50)
                tmp = {0.95 * 0.0333 * 4.6 *10}
 else
                tmp = {0.95 * 0.0333 * 0.1 * 10}
 end
 setfield CaL Gbar {PI*{getfield . dia}*{getfield . len}*{tmp}}

 pope
end

// Fix the Resting Potential


foreach  OBJ ({el /cell/#[][TYPE=compartment]})
	call {OBJ} RESET
	current = 0
	foreach  CHAN ({el {OBJ}/#[][TYPE=tabchannel]})
		call {CHAN} RESET
		call {CHAN} PROCESS
		current = {current} + {getfield {CHAN} Ik}
	end
	tmp = {getfield {OBJ} Em} - {current} * {getfield {OBJ} Rm}
	setfield {OBJ} Em {tmp}
	echo {OBJ} {tmp}
end

foreach  OBJ ({el /cell/#[][TYPE=compartment]})
	setfield {OBJ} initVm -65
end

// Connect Compartments

addmsg /cell/soma /cell/dendrite[1] RAXIAL Ra Vm
// addmsg /cell/dendrite[1] /cell/soma AXIAL Vm
for (i = 2; i <= ({dend_NUM}); i = i + 1)
addmsg /cell/dendrite[{i-1}] /cell/dendrite[{i}] RAXIAL Ra Vm
addmsg /cell/dendrite[{i}] /cell/dendrite[{i-1}] AXIAL     Vm
end
//
end
