//genesis
//
// For demonstration of Migliore CA1 cell on GENESIS.
// H Urakubo, 5/2005
//

// In the demo program, NMDAR current is not supressed.
//
//

//
include Na_soma
include Na_dend
include DR_K_soma
include DR_K_dend
include A_Kprox
include A_Kdist
include CaL
include Poirazi_cell
//
make_cell


//
// Parameters 
//
str TARGET = "/cell/dendrite[5]"

float INITCURR = 500
float INITCOND = 4

float tmax = 1
float dt = 0.0001
setclock 0 {dt}


//
// Functions
//


// AMPAR-EPSP

create AMPAR_object /cell/AMPAR
setfield /cell/AMPAR Esyn 0 Gmax 2 tau 0.003
setfield /cell/AMPAR delay 0.005
addmsg {TARGET} /cell/AMPAR VOLTAGE Vm
addmsg /cell/AMPAR {TARGET} INJECT Isyn

// NMDAR-EPSP

create NMDAR_object /cell/NMDAR
setfield /cell/NMDAR delay 0.005 Glu 0.00012
setfield /cell/NMDAR Ei 0 Gmax 50
addmsg {TARGET} /cell/NMDAR VOLTAGE Vm
addmsg /cell/NMDAR {TARGET} INJECT Ji


// PRE_SPIKING

function PRE_SPIKING
 setfield  /cell/NMDAR flag 1
 setfield  /cell/AMPAR flag 1
end


// CURRENT INJECTION

create AMPAR_object /cell/curr
setfield /cell/curr Gmax 500 tau 0.0005 // 500 pA, 0.5 msec
setfield /cell/curr delay 0
addmsg /cell/curr /cell/soma INJECT G

function CURRENT_INJECTION
 setfield  /cell/curr flag 1
end


// Control

function set_inject(dialog)
 str dialog
 setfield /cell/curr Gmax {getfield {dialog} value}
end

function set_conductance(dialog)
 str dialog
 setfield /cell/input Gmax {getfield {dialog} value}
end


// Run control


function func_run_curr

 step 0.030 -t
 CURRENT_INJECTION
 step 0.030 -t
end

function func_run_EPSP

 step 0.028 -t
 PRE_SPIKING
 step 0.032 -t

end

function func_run_BOTH

 step 0.028 -t
 PRE_SPIKING
 step 0.002 -t
 CURRENT_INJECTION
 step 0.030 -t

end

function make_control
 create xform   /control [10,50,500,190]
 create xlabel  /control/label -hgeom 50 -bg cyan -label "CONTROL PANEL"
 create xbutton /control/RESET -wgeom 20% -script reset
 create xbutton /control/RUN_CURR   -xgeom 0:RESET -ygeom 0:label -wgeom 20% -script func_run_curr
 create xbutton /control/RUN_EPSP   -xgeom 0:RUN_CURR -ygeom 0:label -wgeom 20% -script func_run_EPSP
 create xbutton /control/RUN_BOTH   -xgeom 0:RUN_EPSP -ygeom 0:label -wgeom 20% -script func_run_BOTH
 create xbutton /control/QUIT -xgeom 0:RUN_BOTH -ygeom 0:label -wgeom 20% -script quit
 create xdialog /control/Injection -label "I (pico amperes) 1 msec" -value {INITCURR} -script "set_inject <widget>"
 create xdialog /control/Conductance -label "Conductance" -value {INITCOND} -script "set_conductance <widget>"
 xshow /control
end


// Graph

function make_graph
 float vmin = -80
 float vmax = 40
 float tmax = 0.06
 create xform /data [100, 50, 350, 350]
 create xlabel /data/label -hgeom 10% -label "Poirazi cell"
 create xgraph /data/voltage -hgeom 90% -title "Membrane Potential"
 setfield ^ XUnits sec YUnits mvolt
 setfield ^ xmax {tmax} ymin {vmin} ymax {vmax}
 xshow /data
end


// Graph2

function make_graph2
 float vmin = 0
 float vmax = 50
 float tmax = 0.06
 create xform /data2 [{100 + 350}, 50, 350, 350]
 create xlabel /data2/label -hgeom 10% -label "Poirazi cell"
 create xgraph /data2/voltage -hgeom 90% -title "Active channel current"
 setfield ^ XUnits sec YUnits pA
 setfield ^ xmax {tmax} ymin {vmin} ymax {vmax}
 xshow /data2
end


// Graph3

function make_graph3
 float vmin = 0
 float vmax = 1
 float tmax = 0.06
 create xform /data3 [{100 + 700}, 50, 350, 350]
 create xlabel /data3/label -hgeom 10% -label "Poirazi cell"
 create xgraph /data3/voltage -hgeom 90% -title "Synaptic current"
 setfield ^ XUnits sec YUnits pA
 setfield ^ xmax {tmax} ymin {vmin} ymax {vmax}
 xshow /data3
end


// Graph4

function make_graph4
 float vmin = 0
 float vmax = 1
 float tmax = 0.06
 create xform  /data4 [{100 + 1050}, 50, 350, 350]
 create xlabel /data4/label -hgeom 10% -label "Poirazi cell"
 create xgraph /data4/voltage -hgeom 90% -title "A-K states"
 setfield ^ XUnits sec YUnits (1)
 setfield ^ xmax {tmax} ymin {vmin} ymax {vmax}
 xshow /data4
end


//
// Main script
//

make_control

make_graph

addmsg /cell/soma /data/voltage PLOT Vm *soma *red
addmsg /cell/dendrite[5] /data/voltage PLOT Vm *dend5 *green
addmsg /cell/dendrite[10] /data/voltage PLOT Vm *dend10 *blue
addmsg /cell/dendrite[15] /data/voltage PLOT Vm *dend15 *yellow
addmsg /cell/dendrite[20] /data/voltage PLOT Vm *dend20 *BlueViolet
//addmsg {TARGET} /data/voltage PLOT Vm *target *white

make_graph2

addmsg {TARGET}/Na_dend   /data2/voltage PLOT Ik *I_Na *blue
addmsg {TARGET}/DR_K_dend /data2/voltage PLOT Ik *I_DR-K *green
addmsg {TARGET}/A_Kdist   /data2/voltage PLOT Ik *I_A-K *yellow
addmsg {TARGET}/CaL       /data2/voltage PLOT Gk *I_LCa *BlueViolet

make_graph3

addmsg /cell/AMPAR /data3/voltage PLOT Isyn *AMPAR *red
addmsg /cell/NMDAR /data3/voltage PLOT Ji *NMDAR *blue

//
check 
reset

