
/*
AMPAR current with delay
Revision 1  2005/7/8 H. Urakubo

** Note **

G = Tin/{Tin - Tact}*{exp(-t/Tin) - exp(-t/Tact)}
By assuming Tin = Tact + dT,
  => t/Tact * exp(-t/Tact)
and the normalization factor e = 2.71828 is multiplied.

*/

#include "AMPAR_ext.h"

AMPAR(AMPA,action)
register struct AMPAR_struct *AMPA;
Action 	*action;
{
double	t, dt, ddt, V;
double G1, G2, GG1, GG2, tau1, tau2;
int i, j;

MsgIn	*msg;

    SELECT_ACTION(action){
    case PROCESS :
      
	MSGLOOP(AMPA,msg){
	    case 0:
		V = MSGVALUE(msg,0);
		break;
	}
	t  = SimulationTime();
	dt = Clockrate(AMPA);
	G1 = AMPA->G1;
	G2 = AMPA->G2;
	tau2 = AMPA->tau;
	tau1 = tau2*1.001;

	//
	// Spike stored at buffer
	//
	i = AMPA->stack;
	if (AMPA->flag == 1){
	  AMPA->flag = 0;
	  while(i > 0){
	    AMPA->ttime[i] = AMPA->ttime[i-1];
	    i--;
	  }
	  AMPA->ttime[0] = t + AMPA->delay;
	  AMPA->stack += 1;
	  // printf("Buffered at %lf with delay %g\n", 
	  // t, channel->delay);
	}

	//
	// Input
	//
	i = AMPA->stack;
	if ((i > 0) && (AMPA->ttime[i-1] <= t)){
	   G1 += AMPA->prob;
	   G2 += AMPA->prob;
	   AMPA->stack -=1;
	   //	   printf("Input at %lf\n", t);
	}


	// Integration

        j = ceil(dt/0.0001);
        ddt = dt/(double)(j);
        for (i = 0; i < j; i++){
	 G1 += - ddt * G1 / tau1;
	 G2 += - ddt * G2 / tau2;
	}
	AMPA->G1 = G1;
	AMPA->G2 = G2;

	AMPA->G  = (G1-G2) * 1000 * 2.71828 * AMPA->Gmax;
	AMPA->Isyn = (AMPA->Esyn - V) * AMPA->G;
	break;

    case RESET :
        AMPA->flag  = 0;
        AMPA->stack = 0;
	AMPA->Isyn  = 0;
	AMPA->G1    = 0;
	AMPA->G2    = 0;
	break;
    }
}
