/*
  NMDAR Revision 6
  2005/8/10 H. Urakubo


  Channel kinetics are taken from
  Rycroft and Gibb, 2002, J Neurosci, vol 22(20), pp 8860
  "Direct effects of calmodulinon NMDAR ."

  Voltage dependence of Mg block is taken from
  Shouval 2002, Pros Natl Acad Sci

  Ca2+ flux is estimated from
  Garaschuk et al., 1996, J Physiol, vol 491(3), pp 757
  "Fractional Ca2+ current through somatic and dendritic ."

  phi = 2F/RT
      = 2*(96485 C/mol)/(8.314 J/mol/K)/(273.15+34 K)
      = 75.56 /V
      -> 0.0756 /mV
*/

#include "NMDAR_ext.h"

NMDAR(channel,action)
register struct NMDAR_struct *channel;
Action 	*action;
{
double t, dt, ddt, V, ca, c2, c3, T;
double k_NR_CaM_asso, k_NR_CaM_disso;
double Kfcam1, Kfcam2, Kfcam3, Kfcam4, Kfcam5;
double Kbcam1, Kbcam2, Kbcam3, Kbcam4, Kbcam5;
double k_Glu_NR_CaM_asso3, k_Glu_NR_CaM_disso3;
double k_Glu_NR_CaM_assoo, k_Glu_NR_CaM_dissoo;
double k_c2_c3, k_c3_c2;
double N0[3], N1[3], N2[3], N3[3], No[3];
double NN0[3], NN1[3], NN2[3], NN3[3], NNo[3];
double Kf1[3], Kf2[3], Kb1, Kb2, Kb5, Kb6;
double Mgb;
int i, j, k;

MsgIn	*msg;

    SELECT_ACTION(action){
    case PROCESS :
      ca = 0;
      c2 = 0;
      c3 = 0;
	MSGLOOP(channel,msg){
	    case 0:		/* membrane potential */
		V = MSGVALUE(msg,0);
		break;
	    case 1:		/* 2Ca2+CaM concentration */
		ca = MSGVALUE(msg,0);
		break;
	    case 2:		/* 2Ca2+CaM concentration */
		c2 = MSGVALUE(msg,0);
		break;
	    case 3:		/* 3Ca2+CaM concentration */
		c3 = MSGVALUE(msg,0);
		break;
	}
        dt = Clockrate(channel);
        t  = SimulationTime();
	//
        for (k = 0; k < 3; k++){
        N0[k] = channel->N0[k] ;
        N1[k] = channel->N1[k] ;
        N2[k] = channel->N2[k] ;
        N3[k] = channel->N3[k] ;
        No[k] = channel->No[k] ;
        }

	//
        Kfcam1 = channel->Kfcam1;
        Kbcam1 = channel->Kbcam1;
        Kfcam2 = channel->Kfcam2;
        Kbcam2 = channel->Kbcam2;
        Kfcam3 = channel->Kfcam3;
        Kbcam3 = channel->Kbcam3;
        Kfcam4 = channel->Kfcam4;
        Kbcam4 = channel->Kbcam4;
        Kfcam5 = channel->Kfcam5;
        Kbcam5 = channel->Kbcam5;
        //
	Kf1[0] = channel->Kf1;
	Kf2[0] = channel->Kf2;
	Kf1[1] = channel->Kf5;
	Kf2[1] = channel->Kf6;
	Kf1[2] = channel->Kf5;
	Kf2[2] = channel->Kf6;
	//
	Kb1 = channel->Kb1;
	Kb2 = channel->Kb2;
	Kb5 = channel->Kb5;
	Kb6 = channel->Kb6;
	//
        k_c2_c3 = channel->k_c2_c3;
        k_c3_c2 = channel->k_c3_c2;
	//

        //
        // Spike stored at buffer
        //
        i = channel->stack;
        if (channel->flag == 1){
          channel->flag = 0;
          while(i > 0){
            channel->ttime[i] = channel->ttime[i-1];
            channel->GGlu[i] = channel->GGlu[i-1];
            i--;
          }
          channel->ttime[0] = t + channel->delay;
          channel->GGlu[0]  = channel->Glu;
          channel->stack += 1;
	  /*
          printf("NMDAR buffered at %lf with delay %g\n", 
           t, channel->delay);
	  */
        }

        //
        // Input
        //
        i = channel->stack;
        if ((i > 0) && (channel->ttime[i-1] <= t)){
	  T = channel->GGlu[i-1];
	  for (k = 0; k < 3; k++){
	    NN0[k] = N0[k] * exp(- Kf1[k] * T);
	    NN1[k] = (N0[k] * Kf1[k]) / (Kf2[k] -Kf1[k]);
	    NN1[k] = (exp(-Kf1[k]*T) - exp(-Kf2[k]*T)) * NN1[k];
	    NN1[k] = N1[k] * exp(-Kf2[k]*T) + NN1[k];
	    NN2[k] = N2[k] - (NN1[k]-N1[k]) - (NN0[k]-N0[k]);

	    N0[k] = NN0[k];
	    N1[k] = NN1[k];
	    N2[k] = NN2[k];
	  }
          channel->stack -=1;
          /* printf("NMDAR at %lf\n", t); */
	}

	//
	//
        j = ceil(dt/0.00003);
        ddt = dt/(double)(j);
	//
        for (i = 0; i < j; i++){
	  //
          NN0[0] = N1[0]*Kb1;
          NN1[0] = N2[0]*Kb2  - N1[0]*Kb1;
          NN2[0] = N3[0]*1.8 + No[0]*275 - N2[0]*(Kb2+8+280);
          NN3[0] = N2[0]*8   - N3[0]*1.8;
          NNo[0] = N2[0]*280 - No[0]*275;
          //
          for (k = 1; k < 3; k++){
            NN0[k] = N1[k]*Kb5;
            NN1[k] = N2[k]*Kb6  - N1[k]*Kb5;
            NN2[k] = N3[k]*2   + No[k]*2000 - N2[k]*(Kb6+3+150);
            NN3[k] = N2[k]*3   - N3[k]*2;
            NNo[k] = N2[k]*150 - No[k]*2000;
          }
          //
          // NMDAR binding to 2Ca2+CaM
          //
          NN0[0] += - Kfcam1 * N0[0]*c2 + Kbcam1 * N0[1];
          NN1[0] += - Kfcam2 * N1[0]*c2 + Kbcam2 * N1[1];
          NN2[0] += - Kfcam3 * N2[0]*c2 + Kbcam3 * N2[1]; 
          NN3[0] += - Kfcam4 * N3[0]*c2 + Kbcam4 * N3[1]; 
          NNo[0] += - Kfcam5 * No[0]*c2 + Kbcam5 * No[1];

          NN0[1] += Kfcam1 * N0[0]*c2 - Kbcam1 * N0[1];
          NN1[1] += Kfcam2 * N1[0]*c2 - Kbcam2 * N1[1];
          NN2[1] += Kfcam3 * N2[0]*c2 - Kbcam3 * N2[1];
          NN3[1] += Kfcam4 * N3[0]*c2 - Kbcam4 * N3[1];
          NNo[1] += Kfcam5 * No[0]*c2 - Kbcam5 * No[1];
          //
          // NMDAR binding to 3Ca2+CaM
          //
          NN0[0] += - Kfcam1 * N0[0]*c2 + Kbcam1 * N0[2];
          NN1[0] += - Kfcam2 * N1[0]*c2 + Kbcam2 * N1[2];
          NN2[0] += - Kfcam3 * N2[0]*c2 + Kbcam3 * N2[2]; 
          NN3[0] += - Kfcam4 * N3[0]*c2 + Kbcam4 * N3[2]; 
          NNo[0] += - Kfcam5 * No[0]*c2 + Kbcam5 * No[2];

          NN0[2] += Kfcam1 * N0[0]*c2 - Kbcam1 * N0[2];
          NN1[2] += Kfcam2 * N1[0]*c2 - Kbcam2 * N1[2];
          NN2[2] += Kfcam3 * N2[0]*c2 - Kbcam3 * N2[2];
          NN3[2] += Kfcam4 * N3[0]*c2 - Kbcam4 * N3[2];
          NNo[2] += Kfcam5 * No[0]*c2 - Kbcam5 * No[2];

          //
          // NMDAR-3Ca2+CaM dissociating to NMDAR-2Ca2+CaM + Ca2+
          //
          NN0[1] += - k_c2_c3 * N0[1]*ca + k_c3_c2 * N0[2];
          NN1[1] += - k_c2_c3 * N1[1]*ca + k_c3_c2 * N1[2];
          NN2[1] += - k_c2_c3 * N2[1]*ca + k_c3_c2 * N2[2]; 
          NN3[1] += - k_c2_c3 * N3[1]*ca + k_c3_c2 * N3[2]; 
          NNo[1] += - k_c2_c3 * No[1]*ca + k_c3_c2 * No[2];

          NN0[2] += k_c2_c3 * N0[1]*ca - k_c3_c2 * N0[2];
          NN1[2] += k_c2_c3 * N1[1]*ca - k_c3_c2 * N1[2];
          NN2[2] += k_c2_c3 * N2[1]*ca - k_c3_c2 * N2[2];
          NN3[2] += k_c2_c3 * N3[1]*ca - k_c3_c2 * N3[2];
          NNo[2] += k_c2_c3 * No[1]*ca - k_c3_c2 * No[2];
	  //
          //

	  //
        for (k = 0; k < 3; k++){
        N0[k] += ddt * NN0[k];
        N1[k] += ddt * NN1[k];
        N2[k] += ddt * NN2[k];
        N3[k] += ddt * NN3[k];
        No[k] += ddt * NNo[k];
        }
       }

        for (k = 0; k < 3; k++){
        channel->N0[k] = N0[k];
        channel->N1[k] = N1[k];
        channel->N2[k] = N2[k];
        channel->N3[k] = N3[k];
        channel->No[k] = No[k];
        }
	//
	channel->Nt0 = N0[0]+N1[0]+N2[0]+N3[0]+No[0];
	channel->Nt1 = N0[1]+N1[1]+N2[1]+N3[1]+No[1];
	channel->Nt2 = N0[2]+N1[2]+N2[2]+N3[2]+No[2];
	//

	channel->Mg = 1/(1+0.4202*exp(-0.062*V)); // Mg(1.5)/3.57
	if (V > -0.1 & V < 0.1){
	  channel->Vca = -1/0.0756 + 0.5*V;
	  }
	else{
	  channel->Vca = -V/(1-exp(0.0756*V)) * channel->Mg;
	  }
	channel->Vi  = (channel->Ei - V) * channel->Mg;
	channel->Jca = channel->Vca * channel->Pca * (No[0] + No[1] + No[2]);
	channel->Ji  = channel->Vi  * channel->Gmax * (No[0] + No[1] + No[2]);
	channel->Nopen = (No[0] + No[1] + No[2]);
	//
	break;
	//

    case RESET :
        //
	channel->Jca = 0;
	channel->Ji = 0;
	//
        for (k = 0; k < 3; k++){
        channel->N0[k] = 0;
        channel->N1[k] = 0;
        channel->N2[k] = 0;
        channel->N3[k] = 0;
        channel->No[k] = 0;
        }
	//
        channel->Nt0 = 1;
        channel->N1[0] = 1;
	//
	//channel->fp = fopen("NMDAR.dat","w");
	//
	break;
    }
}

